!function () {
  'use strict';
  var directives = angular.module('app.directives', []);
  //tabs隐藏/显示
  directives.directive('hideTabs', function ($rootScope, $ionicTabsDelegate) {
    return {
      restrict: 'A',
      link: function ($scope, $el, $attrs) {
        $scope.$on('$ionicView.beforeEnter', function (event, data) {
          $scope.$watch($attrs.hideTabs, function (value) {
            $rootScope.hideTabs = value;
          });
        });

        $scope.$on('$ionicView.beforeLeave', function () {
          $rootScope.hideTabs = false;
        });
      }
    };
  });
  //数字加减输入
  directives.directive('inOrDecrement', function () {
    return {
      restrict: 'E',
      scope: {
        min: '=',
        max: '=',
        total: '='
      },
      replace: true,
      template: '<div class="row inOrDec" >\
                  <div><button type="button" class="button button-small icon ion-minus" ng-click="total = total - 1" ng-disabled="total <= min"></button></div>\
                  <div class="padding-left padding-right item-text-wrap cnum">{{total}}</div>\
                  <div><button type="button" class="button button-small icon ion-plus" ng-click="total = total + 1" ng-disabled="total >= max"></button></div>\
                </div>',
      link: function ($scope, $el, $attrs) {

      }
    };
  });
  //拨打电话
  directives.directive('phoneDialer', function ($log) {
    return {
      restrict: 'E',
      scope: {
        telno: '='
      },
      replace: true,
      template: '<span ng-click="call()">{{ telno }}</span>',
      link: function ($scope, $el, $attrs) {
        $scope.call = function () {
          phonedialer.dial($attrs.telno, function (err) {
            if (err == "feature") {
              $log.error("插件不支持拨打电话.");
            }
            if (err == "empty") {
              $log.error("号码为空");
            }
          });
        }
      }
    };
  });
  //拨打电话带icon
  directives.directive('phoneDialerIcon', function ($log) {
    return {
      restrict: 'E',
      scope: {
        telno: '=',
      },
      replace: true,
      template: '<span ng-click="call($event)">'
      + '<span ng-bind="telphone" ng-if="showTelno==\'true\'"></span>'
      + '<i style="padding-left:5px;padding-right:5px;font-size:30px;position:absolute;margin:-4px 0 0 10px;" class="ion ion-ios-telephone-outline calm"></i>'
      + '</span>',
      link: function ($scope, $el, $attrs) {
        $scope.showTelno = $attrs.showtel;
        console.log($attrs.telno,$attrs.telno.length);
        $scope.telphone = $attrs.telno.substring(1,$attrs.telno.length-1 );
        // if ($attrs.telno.length == 13) {
        //   $scope.telphone = $attrs.telno.substring(1, 12);
        // }
        // else if ($attrs.telno.length <= 11 && $attrs.telno.length >= 8) {
        //   $scope.telphone = $attrs.telno;
        // }else{
        //
        //   $scope.telphone = $attrs.telno;
        // }
        $scope.call = function ($event) {
          $event.stopPropagation();
          phonedialer.dial($attrs.telno, function (err) {
            if (err == "feature") {
              $log.error("插件不支持拨打电话.");
            }
            if (err == "empty") {
              $log.error("号码为空");
            }
          });
        }
      }
    };
  });
  //tabs滑动<ion-tabs tabs-swipable> ... </ion-tabs>
  directives.directive('tabsSwipable', function ($log, $ionicGesture) {
    return {
      restrict: 'A',
      require: 'ionTabs',
      link: function ($scope, $el, $attrs, $currentTabs) {
        var onSwipeLeft = function () {
          if ($currentTabs.$element.hasClass('tabs-item-hide')) {
            return;
          }
          var target = $currentTabs.selectedIndex() + 1;
          if (target < $currentTabs.tabs.length) {
            $scope.$apply($currentTabs.select(target));
          }
        };
        var onSwipeRight = function () {
          if ($currentTabs.$element.hasClass('tabs-item-hide')) {
            return;
          }
          var target = $currentTabs.selectedIndex() - 1;
          if (target >= 0) {
            $scope.$apply($currentTabs.select(target));
          }
        };

        var swipeGesture = $ionicGesture.on('swipeleft', onSwipeLeft, $el).on('swiperight', onSwipeRight);
        $scope.$on('$destroy', function () {
          $ionicGesture.off(swipeGesture, 'swipeleft', onSwipeLeft);
          $ionicGesture.off(swipeGesture, 'swiperight', onSwipeRight);
        });
      }
    };
  });
  //角色控制
  directives.directive('hasRoles', function ($log, $compile, Storage) {
    return {
      restrict: 'EA',
      priority: 1001,
      terminal: true,
      compile: function ($el, $attrs) {
        var tagName = $el[0].tagName,
          roles = $attrs[tagName === 'HAS-ROLES' ? 'value' : 'hasRoles'],
          roles = !roles ? [] : roles.split(','),
          userRoles = /*Storage.get('userRoles') || */['admin'],
          intersect = userRoles.filter(function (r) {
            return roles.indexOf(r) > -1
          });
        //$log.log(tagName, $el, $attrs, $scope);
        //$el[intersect.length > 0 ? 'removeClass' : 'addClass']('ng-hide');
        if (intersect.length === 0) {
          switch (tagName) {
            case 'ION-TAB':
              $el.attr('hidden', true);
              break;
            default:
              $el.remove();
          }
        }
        $el.removeAttr('has-roles');//防止循环编译
        return function ($scope) {
          $compile($el)($scope);
        };
      }
    }
  });
  //权限控制
  directives.directive('hasPermission', function ($log, $compile, Storage) {
    return {
      restrict: 'EA',
      priority: 1001,
      terminal: true,
      compile: function ($el, $attrs) {
        var tagName = $el[0].tagName,
          permission = $attrs[tagName === 'HAS-PERMISSION' ? 'value' : 'hasPermission'],
          permission = !permission ? [] : permission.split(','),
          userPermission = /*Storage.get('userRoles') || */['admin'],
          intersect = userPermission.filter(function (p) {
            return permission.indexOf(p) > -1
          });
        //$el[intersect.length > 0 ? 'removeClass' : 'addClass']('ng-hide');
        if (intersect.length === 0) {
          switch (tagName) {
            case 'ION-TAB':
              $el.attr('hidden', true);
              break;
            default:
              $el.remove();
          }
        }
        $el.removeAttr('has-permission');//防止循环编译
        return function ($scope) {
          $compile($el)($scope);
        };
      }
    }
  });
  //ng-repeat完成指令
  directives.directive('repeatFinish', function ($log, $compile, Storage, $ionicScrollDelegate) {
    return {
      link: function (scope, element, attr) {
        if (scope.$last == true) {
          console.log('ng-repeat执行完毕，scroll bottom');
          $ionicScrollDelegate.$getByHandle('small').scrollBottom();
          $ionicScrollDelegate.$getByHandle('bottom').scrollBottom();
          $ionicScrollDelegate.$getByHandle('small').resize();
          scope.$eval(attr.repeatFinish);
        }
      }
    }
  });
  //ng-repeat完成指令
  directives.directive('ngRepeatFinish', function ($log, $compile, Storage, $ionicScrollDelegate) {
    return {
      link: function (scope, element, attr) {
        if (scope.$last == true) {
          scope.$eval(attr.ngRepeatFinish);
        }
      },
      controller: function ($scope) {
        $scope.choosePersonNgRepeatEnd = function () {
          // console.log("11");
          $ionicScrollDelegate.$getByHandle('choosePersonScroll').resize();
          $ionicScrollDelegate.$getByHandle('choosePersonScroll').scrollTop();
        };
        $scope.renderUserNodeEnd = function () {
          console.log("slide to bottom");
          $ionicScrollDelegate.$getByHandle('renderUserNodeScroll').resize();
          $ionicScrollDelegate.$getByHandle('renderUserNodeScroll').scrollBottom();
        };
      }
    }
  });

  directives.directive('chooseType', ['$compile', '$ionicBackdrop',
    function ($compile, $ionicBackdrop) {
      return {
        template: '<div>{{selectType.show}} <span style="float: right" class="dark">筛选</span></div>',
        restrict: 'AE',
        replace: true,
        scope: {
          companies: "=",
          format: '@',
          okHandler: '&',
          initObj: '=',
          loadDateTime: '='
        },
        link: function (scope, elm, attrs) {
          var tem = "<div class='jingyingDynamicChoose datetimeactive'>" +
            "<div class='main'>" +
            "<div  class='header'>{{options.title}}</div>"
            + "<div class='body'>"
            + "<div class='row row-no-padding '>" +
            "<div class='col '><ion-scroll  class='timeContent'>" + "<ul>" +
            "<li ng-repeat='company in companies track by $index' ng-class='{true:\"bar-iccs light\"}[company.choosed]' ng-click='chooseCompany(company)'>" +
            "{{company.name}}" +
            "</li>" +
            "</ul>" + "</ion-scroll>" +
            "</div>" +
            "<div class='col'><ion-scroll  class='yearContent'>" + "<ul>" +
            "<li ng-repeat='year in listdata.years'  ng-class='{true:\"bar-iccs light\"}[year.choosed]' ng-click='chooseYear(year)'>" +
            "{{year.value}}" +
            "</li>" +
            "</ul>" + "</ion-scroll>" +
            "</div>" +
            "<div class='col'><ion-scroll  class='monthContent last'>" + "<ul>" +
            "<li ng-repeat='month in listdata.months'  ng-class='{true:\"bar-iccs light\"}[month.choosed]' ng-click='chooseMonth(month)'>" +
            "{{month.value}}" +
            "</li>" + "" +
            "</ul>" + "</ion-scroll></div>" +
            "</div>"
            + "</div>" +
            "<div class='footer'>" +
            "<span ng-click='ok()'>确定</span><span ng-click='cancel()'>取消</span>" +
            "</div>" +
            "</div>" +
            "</div>";

          var options = {
            title: attrs.title || "Title",
            initCompany: attrs.initcompany || "",
            initYear: attrs.inityear || "",
            initMonth: attrs.initmonth || "",
            yearStart: attrs.yearstart || new Date().getFullYear() - 4,
            yearEnd: attrs.yearend || new Date().getFullYear()
          };
          // var initObj = {
          //   company: options.initCompany,
          //   year: options.initYear,
          //   month: options.initMonth
          // }
          // var initObj = {
          //   company: options.initCompany,
          //   year: options.initYear,
          //   month: options.initMonth
          // }
          var initObj = scope.initObj;
          scope.options = options;
          scope.listdata = {
            years: [],
            months: []
          };

          scope.result = {
            company: '',
            year: '',
            month: ''
          };
          init();
          scope.selectType = {
            show: scope.result.company.name && scope.result.year.value && scope.result.month.value
              ? (scope.result.company.name + "-" + scope.result.year.value + "-" + scope.result.month.value)
              : " "
          };

          function init() {
            initCompanies(scope.companies);
            initYear();
            initMonth();
            initPoint(initObj, scope.companies, scope.listdata.years, scope.listdata.months);

            tem = angular.element(tem);
            $compile(tem)(scope);
            angular.element(document.body).append(tem);
          }

          function initCompanies(obj) {
            if (obj) {
              for (var i = 0; i < obj.length; i++) {
                obj[i]['choosed'] = false;
              }
            }
          }

          function initYear() {
            if (options.yearStart <= options.yearEnd) {
              for (var i = options.yearStart; i <= options.yearEnd; i++) {
                scope.listdata.years.push({value: i, choosed: false});
              }
            }
          }

          function initMonth(max) {
            scope.listdata.months = [];
            if (!max) {
              max = 12;
            }
            for (var i = 1; i <= max; i++) {
              if (i < 10) {
                scope.listdata.months.push({value: "0" + i, choosed: false});
              } else {
                scope.listdata.months.push({value: i, choosed: false});
              }
              if (scope.result.month.value == "0" + i || scope.result.month.value == i) {
                scope.listdata.months[i - 1].choosed = true;
              }
            }
          }

          function initPoint(obj, coms, years, months) {
            if (!obj.company || !obj.year || !obj.month) {
              return;
            }
            scope.result = {
              company: {
                name: obj.company.name,
                id: obj.company.id
              },
              year: {
                value: obj.year
              },
              month: {
                value: obj.month
              }
            }
            for (var i = 0; i < coms.length; i++) {
              if (obj.company.name == coms[i].name) {
                coms[i]['choosed'] = true;
              }
            }
            for (var j = 0; j < years.length; j++) {
              if (obj.year == years[j].value) {
                years[j]['choosed'] = true;
              }
            }
            for (var k = 0; k < months.length; k++) {
              if (obj.month == months[k].value) {
                months[k]['choosed'] = true;
              }
            }
          }

          scope.chooseCompany = function (o) {
            for (var one in scope.companies) {
              scope.companies[one]['choosed'] = false;
            }
            o.choosed = true;
            scope.result.company = o;
          };
          scope.chooseYear = function (o) {
            for (var one in scope.listdata.years) {
              scope.listdata.years[one]['choosed'] = false;
            }
            o.choosed = true;
            scope.result.year = o;
            judgeMonth(scope.result.year.value);
          };
          scope.chooseMonth = function (o) {
            for (var one in scope.listdata.months) {
              scope.listdata.months[one]['choosed'] = false;
            }
            o.choosed = true;
            scope.result.month = o;
          };

          function judgeMonth(year) {
            if (year == new Date().getFullYear()) {
              initMonth(new Date().getMonth() + 1);
            } else {
              initMonth(12);
            }
          }

          elm.on("click", function () {
            show();
          });
          scope.ok = function () {
            scope.selectType = {
              show: scope.result.company.name && scope.result.year.value && scope.result.month.value
                ? (scope.result.company.name + "-" + scope.result.year.value + "-" + scope.result.month.value)
                : " "
            };
            if (scope.okHandler) {
              scope.okHandler({result: scope.result});  //回调结果扩展操作
            }
            hide();
          };
          scope.cancel = function () {
            hide();
          };
          function show() {
            $ionicBackdrop.retain();
            tem.css("display", "block");
          }

          function hide() {
            tem.css("display", "none");
            $ionicBackdrop.release();
          }

          scope.$watch('initObj', function (newValue, oldValue, scope) {
            // init();
            initObj = scope.initObj;
            initPoint(initObj, scope.companies, scope.listdata.years, scope.listdata.months);

            scope.selectType = {
              show: scope.result.company.name && scope.result.year.value && scope.result.month.value
                ? (scope.result.company.name + "-" + scope.result.year.value + "-" + scope.result.month.value)
                : " "
            };

          });
        }
      }
    }
  ]);

  directives.directive('cutImg', function ($log, $compile, Storage, $ionicScrollDelegate) {
    return {
      restrict: 'A',
      link: function (scope, element, attr) {
        var img = element[0];
        var naturalWidth = img.naturalWidth;
        var naturalHeight = img.naturalHeight;
        var widthOrHeight = attr.show; // 头像 边长
        img.onload = function () {
          if (img.complete) {
            element[0].style.marginTop = 0;
            element[0].style.marginLeft = 0;
            element[0].style.height = 'auto';
            element[0].style.width = 'auto';
            naturalWidth = img.naturalWidth;
            naturalHeight = img.naturalHeight;
            if (naturalWidth > naturalHeight) {
              element[0].style.height = widthOrHeight + 'px';
              element[0].style.marginLeft = -((naturalWidth / (naturalHeight / widthOrHeight)) / 2 - widthOrHeight / 2) + 'px';
            } else {
              element[0].style.width = widthOrHeight + 'px';
              element[0].style.marginTop = -((naturalHeight / (naturalWidth / widthOrHeight)) / 2 - widthOrHeight / 2) + 'px';
            }
          }
        }
      }
    }
  });

  directives.directive('autoFocusWhen', ['$log', '$timeout', function ($log, $timeout) {
    return {
      restrict: 'A',
      scope: {
        autoFocusWhen: '='
      },
      link: function (scope, element) {
        scope.$watch('autoFocusWhen', function (newValue) {
          if (newValue) {
            element[0].focus();
          }
        });
        element.on('blur', function () {
          scope.autoFocusWhen = false;
        })
      }
    }
  }]);

  directives.directive('keyboardShow', [function ($log, $timeout) {
    return {
      restrict: 'A',
      scope: {
        keyboard: '='
      },
      link: function (scope, element) {
        element[0].style.marginTop = element[0].parentElement.clientHeight - 460 + 'px';
        // console.log(element[0].parentElement.clientHeight);
      }
    }
  }]);

  //监听事件渲染结束
  directives.directive('onFinishRender', function ($timeout) {
    return {
      restrict: 'A',
      link: function (scope, element, attr) {
        $timeout(function () {
          scope.$emit('ngDomFinish');
        })
      }
    }
  });

}();
