!function () {
  'use strict';
  var filters = angular.module('app.filters', []);
  filters.filter('timeago', function () {
    return function (input, p_allowFuture) {
      var substitute = function (stringOrFunction, number, strings) {
          var string = angular.isFunction(stringOrFunction) ? stringOrFunction(number, dateDifference) : stringOrFunction;
          var value = (strings.numbers && strings.numbers[number]) || number;
          return string.replace(/%d/i, value);
        },
        nowTime = (new Date()).getTime();
      var date = null;
      if (angular.isNumber(date)) {
        date = new Date(date);
      } else if (/^\d+$/.test(input)) {
        date = new Date(parseInt(input, 10));
      } else {
        var s = (input || '').trim().replace(/\.\d+/, '').replace(/-/, '/').replace(/-/, '/').replace(/T/, ' ').replace(/Z/, ' UTC').replace(/([\+\-]\d\d)\:?(\d\d)/, ' $1$2');
        date = new Date(s);
      }
      //refreshMillis= 6e4, //A minute
      var allowFuture = p_allowFuture || false,
        strings = {
          prefixAgo: '',
          prefixFromNow: '',
          suffixAgo: "前",
          suffixFromNow: "刚刚",
          seconds: "小于 1 分钟",
          minute: "约 1 分钟",
          minutes: "%d 分钟",
          hour: "1 小时",
          hours: "约 %d 小时",
          day: "1 天",
          days: "%d 天",
          month: "约 1 个月",
          months: "%d 个月",
          year: "约 1 年",
          years: "%d 年"
        },
        dateDifference = nowTime - date,
        words,
        seconds = Math.abs(dateDifference) / 1000,
        minutes = seconds / 60,
        hours = minutes / 60,
        days = hours / 24,
        years = days / 365,
        separator = strings.wordSeparator === undefined ? " " : strings.wordSeparator,


        prefix = strings.prefixAgo,
        suffix = strings.suffixAgo;

      if (allowFuture) {
        if (dateDifference < 0) {
          prefix = strings.prefixFromNow;
          suffix = strings.suffixFromNow;
        }
      }

      words = seconds < 45 && substitute(strings.seconds, Math.round(seconds), strings) ||
        seconds < 90 && substitute(strings.minute, 1, strings) ||
        minutes < 45 && substitute(strings.minutes, Math.round(minutes), strings) ||
        minutes < 90 && substitute(strings.hour, 1, strings) ||
        hours < 24 && substitute(strings.hours, Math.round(hours), strings) ||
        hours < 42 && substitute(strings.day, 1, strings) ||
        days < 30 && substitute(strings.days, Math.round(days), strings) ||
        days < 45 && substitute(strings.month, 1, strings) ||
        days < 365 && substitute(strings.months, Math.round(days / 30), strings) ||
        years < 1.5 && substitute(strings.year, 1, strings) ||
        substitute(strings.years, Math.round(years), strings);
      //console.log(prefix+words+suffix+separator);
      prefix.replace(/ /g, '');
      words.replace(/ /g, '');
      suffix.replace(/ /g, '');
      // console.log(prefix+words+suffix+separator);
      if (prefix + words + suffix + separator == "小于 1 分钟前 ") {
        return ("1 分钟内");
      } else
        return (prefix + words + suffix + separator);
    };
  });
  filters.filter('checkType', function () {
    return function (type) {
      return type == 1 ? '线上支付' : '线下支付';
    };
  });
  filters.filter('ddjlIcon', function () {
    return function (status) {
      return status == 0 ? 'modules/portal/img/icon/ycl.png' : 'modules/portal/img/icon/clz.png';
    };
  });
  filters.filter('html_safe', function ($sce) {
    return function (text) {
      return $sce.trustAsHtml(text);
    };
  });
  filters.filter('message_img', function (ENV) {
    return function (img) {
      return !img ? 'modules/portal/img/icon/icons_21.png' : ENV.homeImages + img;
    };
  });
  filters.filter('html_title', function (ENV) {
    return function (title) {
      if (!title) return title;
      return title.replace(/(\n)/g, "").replace(/(\t)/g, "").replace(/(\r)/g, "").replace(/<\/?[^>]*>/g, "").replace(/<\/?[^>]*>/g, "");
    };
  });

  filters.filter('gzcl_title', function () {
    return function (title) {
      if (title == 0) {
        return '空调保修';
      } else if (title == 1) {
        return '电梯维修';
      } else if (title == 2) {
        return '照明保修';
      } else if (title == 3) {
        return '现场保洁';
      } else if (title == 4) {
        return '房屋维修';
      } else {
        return '其他';
      }
    };
  });
  filters.filter('week_num', function () {

    return function (date) {
      var num = (new Date(date)).getDay();
      if (num == 0) {
        return '周日';
      } else if (num == 1) {
        return '周一';
      } else if (num == 2) {
        return '周二';
      } else if (num == 3) {
        return '周三';
      } else if (num == 4) {
        return '周四';
      } else if (num == 5) {
        return '周五';
      } else if (num == 6) {
        return '周六';
      }
    };
  });
  filters.filter('showCutstr', function () {
    return function (string, num) {
      if (string && string.length > num) {
        // console.log(string.substring(0,50));
        return string.substring(0, num) + "...";
      } else {
        return string;
      }
    };
  });
  filters.filter('secondToHour', function () {
    return function (timestamp) {
      var timeStr = null, hour = 0, second = 0;
      var time = timestamp / 1000;
      if (time <= 0)
        return "00:00";
      else {
        var minute = Math.floor(time / 60);
        if (minute < 60) {
          second = time % 60;
          timeStr = unitFormat(minute) + ":" + unitFormat(second);
        } else {
          hour = Math.floor(minute / 60);
          if (hour > 99)
            return "99:59:59";
          minute = minute % 60;
          second = time - hour * 3600 - minute * 60;
          timeStr = unitFormat(hour) + ":" + unitFormat(minute) + ":" + unitFormat(second);
        }
        return timeStr;
      }
      function unitFormat(i) {
        var retStr = null;
        if (i >= 0 && i < 10)
          retStr = "0" + i;
        else
          retStr = "" + i;
        return retStr;
      }
    };

  });

  filters.filter('judgeObjInArr', function () {//判断arr中是否存在obj
    return function (arr, obj, key1, key2) {
      if (key2==undefined ) {
        key2 = key1;
      }
      // console.log(key1, key2);
      for (var i = 0; i < arr.length; i++) {
        if (arr[i][key1] == obj[key2]) {
          return i + 1;//防止 i=0 与 false 冲突，故 i+1
        }
      }
      return false;
    };

  });

}();
