define(['communication.boot'], function (require) {
  'use strict';

  var controller = angular.module('communication.controllers');

  controller.controller('CommunicationRecordController', function (ENV, $scope, $log, $timeout, $rootScope, $ionicPopup, $state, $ionicHistory, $ionicLoading, $interval, $ionicScrollDelegate, Storage, CommunicationService) {
    $scope.goBack = function () {
      $ionicHistory.goBack();
    };
    $scope.showNull = false;
    $scope.hasMore = false;
    $scope.dataList = [];
    $scope.start = 0;
    $scope.limit = 15;
    $scope.form = {
      troubleName: ''
    };

    $scope.goDetail = function (item) {
      $state.go('communicationDetail', {id: item.id})
    };

    $scope.onPullDown = function () {
      $scope.showSearch = true;
    };

    $scope.onPullDownData = function () {
      $scope.start = 0;
      $scope.dataList = [];
      $scope.loadMore();
    }

    $scope.onPullUp = function () {
      $scope.showSearch ? $scope.showSearch = false : '';
    };

    $scope.search = function () {
      $scope.start = 0;
      $scope.dataList = [];
      $scope.loadMore();
    };

    $scope.loadMore = function () {
      CommunicationService.commonTroubleList($scope.form.troubleName, $scope.start, $scope.limit).success(function (res) {
        var records = res.record;
        $scope.start = $scope.start + records.length;
        $scope.dataList = $scope.dataList.concat(records);
        $scope.showNull = !$scope.dataList.length > 0;
        if (records.length >= $scope.limit) {
          $scope.hasMore = true;
        } else {
          $scope.hasMore = false;
        }
        $scope.$broadcast('scroll.refreshComplete');
        $scope.$broadcast('scroll.infiniteScrollComplete');
      }).error(function (res) {
        if (res.errorCode == '000002') {
          var confirmPopup = $ionicPopup.alert({
            title: '提示信息',
            template: '该帐号已在其他设备登录！',
            okText: '确定',
            okType: 'button-assertive'
          });
          confirmPopup.then(function (res) {
            if (res) {
              Storage.remove('isLogged');
              Storage.remove('userInfo');
              Storage.remove('menuList');
              $state.go('login');
            }
          });
        }
      });
    };
    $scope.loadMore();
  });
  controller.controller('AddCommunicationController', function (ENV, $scope, $log, $timeout, $rootScope, $ionicPopup, $state, $ionicHistory, $ionicLoading, $interval, $ionicScrollDelegate, Storage, CommunicationService, $ionicActionSheet, $cordovaImagePicker) {
    $scope.form = {
      title: '',
      desc: ''
    };
    $scope.imgs = [];  //imgs

    $scope.showMsg = function (msg) {
      $ionicLoading.show({
        template: msg,
        noBackdrop: true,
        duration: 3000
      });
    };
    $scope.shouBigImage = function (list,index) {
      var arr = [];
      list.forEach(function (item) {
        var o = {};
        o.picUrl = item;
        arr.push(o);
      });
      console.log(arr)
      PicturePreview.picturePreview(arr, index, '', function (success) {
        }, function (error) {
        }
      );
    };

    $scope.goBack = function () {
      $ionicHistory.goBack();
    };

    $scope.onAddPic = function () {
      if($scope.imgs.length >= 10) {
        $scope.showMsg('最多上传10张图片')
        return
      }
      $ionicActionSheet.show({
        buttons: [
          {text: '立即拍摄'},
          {text: '从相册中选择'}
        ],
        titleText: '请选择图片来源',
        cancelText: '返回',
        cancel: function () {
          $log.log('cancel');
        },
        buttonClicked: function (index) {
          switch (index) {
            case 0:
              $scope.onTakePhoto();  // 调用照相功能
              break;
            case 1:
              $scope.onAddFromAlbum();  // 调用选择图片功能
              break;
            default:
              break;
          }
          return true;
        }
      });
    };

    //调用选择图片功能
    $scope.onAddFromAlbum = function () {
      var num = 10 - $scope.imgs.length;
      var options = {
        maximumImagesCount: num === 10? 9 : num, //需要显示的图片的数量
        width: 800,
        height: 800,
        quality: 100
      };
      $cordovaImagePicker.getPictures(options)
        .then(function (results) {
          if(Array.isArray(results)) {
            for (var i = 0; i < results.length; i++) {
              $scope.imgs.push(results[i]);
            }
            $scope.$apply();
          }
        }, function (error) {
          // error getting photos
        });
    };

    // 照相功能
    $scope.onTakePhoto = function () {
      var options = {
        quality: 100,
        destinationType: Camera.DestinationType.FILE_URI,
        //sourceType: Camera.PictureSourceType.SAVEDPHOTOALBUM,
        encodingType: Camera.EncodingType.JPEG,
        mediaType: Camera.MediaType.PICTURE,
        targetHeight: 450,
        targetWidth: 350
      };
      navigator.camera.getPicture(function (fileURL) {
          $scope.imgs.push(fileURL);
          $scope.$apply();
        },
        function () {//if error
        },
        options);
    };

    // 删除图片
    $scope.deleteImg = function (index) {
      var confirmPopup = $ionicPopup.confirm({
        title: '删除图片',
        template: '确定删除第' + (index + 1) + '张图片吗?',
        cancelText: '取消',
        okText: '确定',
        okType: 'button-assertive'
      });
      confirmPopup.then(function (res) {
        if (res) {
          $scope.imgs.splice(index, 1);
          $scope.$apply();
        } else {
          console.log('You are not sure');
        }
      });
    };

    $scope.upload = function (fileURL, troubleId, final) {
      var options = new FileUploadOptions();
      options.fileKey = "file";
      options.fileName = fileURL.substr(fileURL.lastIndexOf('/') + 1);
      if (options.fileName.indexOf('?') != -1) {
        options.fileName = options.fileName.substring(0, options.fileName.indexOf('?'));
      }
      options.mimeType = "image/jpeg";
      var params = {
        usertoken: Storage.get('userInfo').usertoken,
        tableId: troubleId,
        tableName: "cm_common_trouble"
      };
      options.params = params;
      var ft = new FileTransfer();
      ft.upload(
        fileURL,
        encodeURI(ENV.api + "/commonTrouble/doUploadPic"),
        function () {
          if (final) {//如果是最后一张
            $timeout(function () {
              $ionicLoading.hide();
              $scope.goBack()
            }, 1000);
          }
        },
        function () {//失败
          console.log("图片上传失败");
          $ionicLoading.hide();
        },
        options
      );
    };

    //提交
    $scope.submit = function () {
      $ionicLoading.show();
      if ($scope.form.title.length == '') {
        $scope.showMsg('标题不能为空');
        return
      }
      if ($scope.form.desc.length == '') {
        $scope.showMsg('内容不能为空');
        return
      }
      CommunicationService.addTrouble($scope.form.title, $scope.form.desc).success(function (res) {
        var imgArr = $scope.imgs;
        if (imgArr.length == 0) {// 没有图片
          $timeout(function () {
            $ionicLoading.hide();
            $scope.goBack();
          }, 1000);
        } else {// 有图片
          angular.forEach(imgArr, function (data, index, array) {
            //data等价于array[index]
            var fileURL = data;
            if (index == imgArr.length - 1) {  // 是否是最后一张
              $scope.upload(fileURL, res.record.id, true);
            } else {
              $scope.upload(fileURL, res.record.id, false);
            }
          });
        }
      }).error(function (res) {
        if (res.errorCode == '000002') {
          var confirmPopup = $ionicPopup.alert({
            title: '提示信息',
            template: '该帐号已在其他设备登录！',
            okText: '确定',
            okType: 'button-assertive'
          });
          confirmPopup.then(function (res) {
            if (res) {
              Storage.remove('isLogged');
              Storage.remove('userInfo');
              Storage.remove('menuList');
              $state.go('login');
            }
          });
        }
      })

    }
  });
  controller.controller('CommunicationDetailController', function (ENV, $scope, $log, $timeout, $rootScope, $ionicPopup, $state, $ionicHistory, $ionicLoading, $interval, $ionicScrollDelegate, Storage, CommunicationService, $stateParams) {
    $scope.id = $stateParams.id;
    $scope.detailData = null;
    $scope.replayData = [];

    /**
     *
     * @param arr 数组：picUrl
     * @param index 索引
     * @param api api+picUrl = 图片地址
     */
    // showImgs: function (arr, index, api) {
    //   PicturePreview.picturePreview(arr, index, api, function (success) {
    //     }, function (error) {
    //     }
    //   );
    // },
    $scope.shouBigImage = function (list,index) {
      var arr = [];
      list.forEach(function (item) {
        var o = {};
        o.picUrl = '/file/getPic?id='+item.id+'&isCompress=false';
        arr.push(o);
      });
      PicturePreview.picturePreview(arr, index, ENV.api, function (success) {
        }, function (error) {
        }
      );
    };


    $scope.goBack = function () {
      $ionicHistory.goBack();
    };

    $scope.goReplay = function () {
      $state.go('communicationReplay', {id: $scope.id})
    }

    CommunicationService.getTroubleDetail($scope.id).success(function (res) {
      $scope.detailData = res.record;
    }).error(function (res) {
      if (res.errorCode == '000002') {
        var confirmPopup = $ionicPopup.alert({
          title: '提示信息',
          template: '该帐号已在其他设备登录！',
          okText: '确定',
          okType: 'button-assertive'
        });
        confirmPopup.then(function (res) {
          if (res) {
            Storage.remove('isLogged');
            Storage.remove('userInfo');
            Storage.remove('menuList');
            $state.go('login');
          }
        });
      }
    });

    CommunicationService.getReplayList($scope.id).success(function (res) {
      $scope.replayData = res.record;
    }).error(function (erro) {
      console.log(erro)
    });
  });
  controller.controller('CommunicationReplayController', function (ENV, $scope, $log, $timeout, $rootScope, $ionicPopup, $state, $ionicHistory, $ionicLoading, $interval, $ionicScrollDelegate, Storage, CommunicationService, $ionicActionSheet, $cordovaImagePicker, $stateParams) {
    $scope.form = {
      content: ''
    };
    $scope.id = $stateParams.id;
    $scope.imgs = [];  //imgs

    $scope.showMsg = function (msg) {
      $ionicLoading.show({
        template: msg,
        noBackdrop: true,
        duration: 3000
      });
    };

    $scope.shouBigImage = function (list,index) {
      var arr = [];
      list.forEach(function (item) {
        var o = {};
        o.picUrl = item;
        arr.push(o);
      });
      console.log(arr)
      PicturePreview.picturePreview(arr, index, '', function (success) {
        }, function (error) {
        }
      );
    };

    $scope.goBack = function () {
      $ionicHistory.goBack();
    };

    $scope.onAddPic = function () {
      if($scope.imgs.length >= 10) {
        $scope.showMsg('最多上传10张图片')
        return
      }
      $ionicActionSheet.show({
        buttons: [
          {text: '立即拍摄'},
          {text: '从相册中选择'}
        ],
        titleText: '请选择图片来源',
        cancelText: '返回',
        cancel: function () {
          $log.log('cancel');
        },
        buttonClicked: function (index) {
          switch (index) {
            case 0:
              $scope.onTakePhoto();  // 调用照相功能
              break;
            case 1:
              $scope.onAddFromAlbum();  // 调用选择图片功能
              break;
            default:
              break;
          }
          return true;
        }
      });
    };

    //调用选择图片功能
    $scope.onAddFromAlbum = function () {
      var num = 10 - $scope.imgs.length;
      var options = {
        maximumImagesCount: num === 10? 9 : num, //需要显示的图片的数量
        width: 800,
        height: 800,
        quality: 100
      };
      $cordovaImagePicker.getPictures(options)
        .then(function (results) {
          if(Array.isArray(results)) {
            for (var i = 0; i < results.length; i++) {
              $scope.imgs.push(results[i]);
            }
            $scope.$apply();
          }
        }, function (error) {
          // error getting photos
        });
    };

    // 照相功能
    $scope.onTakePhoto = function () {
      var options = {
        quality: 100,
        destinationType: Camera.DestinationType.FILE_URI,
        //sourceType: Camera.PictureSourceType.SAVEDPHOTOALBUM,
        encodingType: Camera.EncodingType.JPEG,
        mediaType: Camera.MediaType.PICTURE,
        targetHeight: 450,
        targetWidth: 350
      };
      navigator.camera.getPicture(function (fileURL) {
          $scope.imgs.push(fileURL);
          $scope.$apply();
        },
        function () {//if error
        },
        options);
    };

    // 删除图片
    $scope.deleteImg = function (index) {
      var confirmPopup = $ionicPopup.confirm({
        title: '删除图片',
        template: '确定删除第' + (index + 1) + '张图片吗?',
        cancelText: '取消',
        okText: '确定',
        okType: 'button-assertive'
      });
      confirmPopup.then(function (res) {
        if (res) {
          $scope.imgs.splice(index, 1);
          $scope.$apply();
        } else {
          console.log('You are not sure');
        }
      });
    };

    $scope.upload = function (fileURL, troubleId, final) {
      var options = new FileUploadOptions();
      options.fileKey = "file";
      options.fileName = fileURL.substr(fileURL.lastIndexOf('/') + 1);
      if (options.fileName.indexOf('?') != -1) {
        options.fileName = options.fileName.substring(0, options.fileName.indexOf('?'));
      }
      options.mimeType = "image/jpeg";
      var params = {
        usertoken: Storage.get('userInfo').usertoken,
        tableId: troubleId,
        tableName: "cm_common_trouble_reply"
      };
      options.params = params;
      var ft = new FileTransfer();
      ft.upload(
        fileURL,
        encodeURI(ENV.api + "/commonTrouble/doUploadPic"),
        function () {
          if (final) {//如果是最后一张
            $timeout(function () {
              $ionicLoading.hide();
              $scope.goBack()
            }, 1000);
          }
        },
        function () {//失败
          console.log("图片上传失败");
          $ionicLoading.hide();
        },
        options
      );
    };

    //提交
    $scope.submit = function () {
      $ionicLoading.show();
      if ($scope.form.content.length == '') {
        $scope.showMsg('回复内容不能为空');
        return
      }
      CommunicationService.doReplay($scope.id,$scope.form.content).success(function (res) {
        var imgArr = $scope.imgs;
        if (imgArr.length == 0) {// 没有图片
          $timeout(function () {
            $ionicLoading.hide();
            $scope.goBack();
          }, 1000);
        } else {// 有图片
          angular.forEach(imgArr, function (data, index, array) {
            //data等价于array[index]
            var fileURL = data;
            if (index == imgArr.length - 1) {  // 是否是最后一张
              $scope.upload(fileURL, res.record.id, true);
            } else {
              $scope.upload(fileURL, res.record.id, false);
            }
          });
        }
      }).error(function (res) {
        if (res.errorCode == '000002') {
          var confirmPopup = $ionicPopup.alert({
            title: '提示信息',
            template: '该帐号已在其他设备登录！',
            okText: '确定',
            okType: 'button-assertive'
          });
          confirmPopup.then(function (res) {
            if (res) {
              Storage.remove('isLogged');
              Storage.remove('userInfo');
              Storage.remove('menuList');
              $state.go('login');
            }
          });
        }
      })

    }
  });

  return controller;
});
