define(['communication.boot'], function(require){
  'use strict';

  var service = angular.module('communication.services');
  service.factory('CommunicationService', function($q, $http, $log, $base64, ENV,Storage) {
    return {
      commonTroubleList: function(troubleName,start,limit){
        var deferred = $q.defer(),
          promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/commonTrouble/list',
          dataType: "json",
          params:{
            start:start,
            limit:limit,
            troubleName: troubleName || '',
            usertoken:Storage.get('userInfo').usertoken
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
          promise.then(fn);
          return promise;
        }
        promise.error = function(fn) {
          promise.then(null, fn);
          return promise;
        }
        return promise;
      },
      addTrouble: function(title,desc){
        var deferred = $q.defer(),
          promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/commonTrouble/saveTrouble',
          headers: {'Content-Type': 'application/x-www-form-urlencoded'},
          transformRequest: function (obj) {
            var str = [];
            for (var p in obj) {
              str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
            }
            return str.join("&");
          },
          data:{
            title: title || '',
            description: desc || '',
            usertoken:Storage.get('userInfo').usertoken
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
          promise.then(fn);
          return promise;
        }
        promise.error = function(fn) {
          promise.then(null, fn);
          return promise;
        }
        return promise;
      },
      getTroubleDetail: function(id){
        var deferred = $q.defer(),
          promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/commonTrouble/detail',
          dataType: "json",
          params:{
            troubleId: id,
            usertoken:Storage.get('userInfo').usertoken
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
          promise.then(fn);
          return promise;
        }
        promise.error = function(fn) {
          promise.then(null, fn);
          return promise;
        }
        return promise;
      },
      getReplayList: function(id){
        var deferred = $q.defer(),
          promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/commonTrouble/replayList',
          dataType: "json",
          params:{
            troubleId: id,
            usertoken:Storage.get('userInfo').usertoken
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
          promise.then(fn);
          return promise;
        }
        promise.error = function(fn) {
          promise.then(null, fn);
          return promise;
        }
        return promise;
      },
      doReplay: function(id,content){
        var deferred = $q.defer(),
          promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/commonTrouble/doReplay',
          headers: {'Content-Type': 'application/x-www-form-urlencoded'},
          transformRequest: function (obj) {
            var str = [];
            for (var p in obj) {
              str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
            }
            return str.join("&");
          },
          data:{
            troubleId:id,
            content: content,
            usertoken:Storage.get('userInfo').usertoken
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
          promise.then(fn);
          return promise;
        }
        promise.error = function(fn) {
          promise.then(null, fn);
          return promise;
        }
        return promise;
      }
    };
  });
  return service;
});
