define(['portal.boot'], function(require){
  'use strict';

  var service = angular.module('portal.services');
  service.factory('AuthService', function($q, $http, $log, $base64, ENV) {
    return {
      login: function(username, password){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/user/doLogin',
          dataType: "json",
          params: {
            userName: username,
            password: password
          }
        }).success(function(res){
          if(res && res.success){
            deferred.resolve(res.record);
          } else {
            deferred.reject(res);
          }
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      updateToken: function(token){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/login/updateToken',
          dataType: "json",
          params: {
            token: $base64.encode(token)
          }
        }).success(function(res){
          $log.log(res);
          if(res && res.success){
            deferred.resolve(res.record);
          } else {
            deferred.reject('更新Token失败，' + res.msg);
          }
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      logout: function(){
        //TODO
      },
      getNum: function(username){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/login/getCode',
          dataType: "json",
          params: {
            telephone: $base64.encode(username)
          }
        }).success(function(res){
            deferred.resolve(res);
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      isCheck: function(usertoken){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/user/isCheck',
          dataType: "json",
          params: {
            usertoken: usertoken
          }
        }).success(function(res){
            deferred.resolve(res);
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      getNumByTel: function(telephone,sysCode,mac){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.uapi + '/user/getCode',
          dataType: "json",
          params: {
            telephone : telephone,
            sysCode : sysCode,
            mac : mac
          }
        }).success(function(res){
            deferred.resolve(res);
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      checkNum: function(username, num){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/login/checkCode',
          dataType: "json",
          params: {
              telephone: $base64.encode(username),
              code: $base64.encode(num)
          }
        }).success(function(res){
            deferred.resolve(res);
        });
        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      checkNumByTel: function(telephone, code, sysCode, mac){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.uapi + '/user/checkCode',
          dataType: "json",
          params: {
              telephone: telephone,
              code: code,
              sysCode: sysCode,
              mac: mac
          }
        }).success(function(res){
            deferred.resolve(res);
        });
        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      updatePassword: function(telephone, password, password2, checkNum){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.api + '/login/setNewPassword2',
          dataType: "json",
          params: {
            telephone : $base64.encode(telephone),
	          pw1 :  $base64.encode(password),
					  pw2 :  $base64.encode(password2),
            code :  $base64.encode(checkNum)
          }
        }).success(function(res){
            deferred.resolve(res);
        });
        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      updatePasswordByTel: function(telephone, pw1, pw2, code, sysCode, mac){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.uapi + '/user/setNewPassword',
          dataType: "json",
          params: {
            telephone : telephone,
            pw1 :  pw1,
            pw2 :  pw2,
            code :  code,
            sysCode :  sysCode,
            mac :  mac
          }
        }).success(function(res){
            deferred.resolve(res);
        });
        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      getAccessToken: function(username, password){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.apiGateway,
          dataType: "json",
          params: {
            grant_type : "password",
            username : username,
            password : password
          },
          headers: {
                "Authorization": "Basic Y2xpZW50X2FwcF9pZDpzZWNyZXQ="
          }
        }).success(function(res){
            deferred.resolve(res);
        }).error(function(res) {
            deferred.reject(res);
        });
        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      getAccessTokenByRefreshToken: function(refreshToken){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.apiGateway,
          dataType: "json",
          params: {
            grant_type : "refresh_token",
            refresh_token : refreshToken
          },
          headers: {
                "Authorization": "Basic Y2xpZW50X2FwcF9pZDpzZWNyZXQ="
          }
        }).success(function(res){
            deferred.resolve(res);
        }).error(function(res) {
            deferred.reject(res);
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      revokeToken: function(refreshToken){
        var deferred = $q.defer(),
            promise = deferred.promise;
        $http({
          method: 'POST',
          url: ENV.apiLogout,
          dataType: "json",
          params: {
            token : refreshToken
          },
          headers: {
                "Authorization": "Basic Y2xpZW50X2FwcF9pZDpzZWNyZXQ="
          }
        }).success(function(res){
            deferred.resolve(res);
        }).error(function(res) {
            deferred.reject(res);
        });

        promise.success = function(fn) {
            promise.then(fn);
            return promise;
        }
        promise.error = function(fn) {
            promise.then(null, fn);
            return promise;
        }
        return promise;
      },
      changePassword: function(oldPassword, newPassword, confirmPassword, usertoken){
            var deferred = $q.defer(),
                promise = deferred.promise;
            $http({
              method: 'POST',
              url: ENV.api + '/user/doChangePassword',
              dataType: "json",
              params: {
                oldPassword : oldPassword,
                newPassword : newPassword,
                confirmPassword : confirmPassword,
                usertoken : usertoken
              }
            }).success(function(res){
              if(res && res.success){
                deferred.resolve(res);
              } else {
                deferred.reject(res);
              }
            });

            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
          },
      menuList: function(usertoken){
            var deferred = $q.defer(),
                promise = deferred.promise;
            $http({
              method: 'POST',
              url: ENV.api + '/user/menuList',
              dataType: "json",
              params: {
                usertoken : usertoken
              }
            }).success(function(res){
              if(res && res.success){
                deferred.resolve(res);
              } else {
                deferred.reject(res);
              }
            });

            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
          }
    };
  });
  return service;
});
